Community — Invenio 3.4.0a8 documentation

# Community

Notes on getting involved, contributing, legal information and release notes are here for the interested.

- Contributing
  - Contribution guide
  - Style guide
  - Translation guide
  - Maintainer’s guide
- Security policy
  - Reporting security issues
  - Supported versions
  - Disclosure of security issues
  - Severity levels
- Governance
- Code of Conduct
- License
- History
  - From software to framework
  - What happened to Invenio v2?
  - Mailing lists